@@ -51,7 +51,7 @@
 using namespace IncidenceEditorNG;
 
 IncidenceAttachment::IncidenceAttachment(Ui::EventOrTodoDesktop *ui)
-    : IncidenceEditor(0),
+    : IncidenceEditor(nullptr),
       mUi(ui),
       mPopupMenu(new QMenu)
 {
@@ -74,8 +74,7 @@ void IncidenceAttachment::load(const KCalCore::Incidence::Ptr &incidence)
     mAttachmentView->clear();
 
     KCalCore::Attachment::List attachments = incidence->attachments();
-    KCalCore::Attachment::List::ConstIterator it;
-    for (it = attachments.constBegin(); it != attachments.constEnd(); ++it) {
+    for (KCalCore::Attachment::List::ConstIterator it = attachments.constBegin(), end = attachments.constEnd(); it != end; ++it) {
         new AttachmentIconItem((*it), mAttachmentView);
     }
 
@@ -201,7 +200,7 @@ void IncidenceAttachment::removeSelectedAttachments()
     QString labelsStr = labels.join(QStringLiteral("<nl/>"));
 
     if (KMessageBox::questionYesNo(
-                0,
+                nullptr,
                 xi18nc("@info",
                        "Do you really want to remove these attachments?<nl/>%1", labelsStr),
                 i18nc("@title:window", "Remove Attachments?"),
@@ -241,13 +240,13 @@ void IncidenceAttachment::saveAttachment(QListWidgetItem *item)
     KCalCore::Attachment::Ptr att = attitem->attachment();
 
     // get the saveas file name
-    QString saveAsFile = QFileDialog::getSaveFileName(0, i18nc("@title", "Save Attachment"),
+    QString saveAsFile = QFileDialog::getSaveFileName(nullptr, i18nc("@title", "Save Attachment"),
                          att->label());
 
     if (saveAsFile.isEmpty() ||
             (QFile(saveAsFile).exists() &&
              (KMessageBox::warningYesNo(
-                  0,
+                  nullptr,
                   i18nc("@info", "%1 already exists. Do you want to overwrite it?",
                         saveAsFile)) == KMessageBox::No))) {
         return;
@@ -262,7 +261,7 @@ void IncidenceAttachment::saveAttachment(QListWidgetItem *item)
     // save the attachment url
     auto job = KIO::file_copy(sourceUrl, QUrl::fromLocalFile(saveAsFile));
     if (!job->exec() && job->error()) {
-        KMessageBox::error(0, job->errorString());
+        KMessageBox::error(nullptr, job->errorString());
     }
 }
 
@@ -289,14 +288,14 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
     if (att->isUri()) {
         Q_EMIT openURL(QUrl(att->uri()));
     } else {
-        KRun::runUrl(mAttachmentView->tempFileForAttachment(att), att->mimeType(), 0, true);
+        KRun::runUrl(mAttachmentView->tempFileForAttachment(att), att->mimeType(), nullptr, true);
     }
 }
 
 void IncidenceAttachment::showContextMenu(const QPoint &pos)
 {
     QListWidgetItem *item = mAttachmentView->itemAt(pos);
-    const bool enable = item != 0;
+    const bool enable = item != nullptr;
 
     int numSelected = 0;
     for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
@@ -418,7 +417,7 @@ void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
         probablyWeHaveUris = true;
     }
     QMenu menu;
-    QAction *linkAction = 0, *cancelAction;
+    QAction *linkAction = nullptr, *cancelAction;
     if (probablyWeHaveUris) {
         linkAction = menu.addAction(QIcon::fromTheme(QStringLiteral("insert-link")), i18nc("@action:inmenu", "&Link here"));
         // we need to check if we can reasonably expect to copy the objects
@@ -598,7 +597,7 @@ void IncidenceAttachment::addUriAttachment(const QString &uri,
         }
     } else {
         auto job = KIO::storedGet(QUrl(uri));
-        KJobWidgets::setWindow(job, 0);
+        KJobWidgets::setWindow(job, nullptr);
         if (job->exec()) {
             const QByteArray data = job->data();
             addDataAttachment(data, mimeType, label);
